@@ -43,10 +43,11 @@
 	$admin_email = $_SESSION['admin_email'];
 	$admin_gbemail = $_SESSION['admin_gbemail'];
 
+	$server_name = $_SERVER["SERVER_NAME"];
 	$gb_path = $_SERVER["SCRIPT_NAME"];
 	$gb_path = str_replace("install/install.php", "", $gb_path);
 
-	$h_domain = $_SERVER["HTTP_HOST"];
+	$h_domain = "www.".$_SERVER["SERVER_NAME"];
 
 	// ++++++++++++++++++++++++++++++++++ //
 
@@ -57,7 +58,7 @@
 	$sql[1] = "CREATE TABLE ".$db_prefix."captcha (
 		  `code` VARCHAR( 11 ) NOT NULL ,
 		  PRIMARY KEY ( `code` )
-		  ) TYPE = MYISAM;";
+		  )";
 
 	$sql[2] = "INSERT INTO ".$db_prefix."captcha ( `code` ) VALUES ( 'ABCDEF' );";
 
@@ -65,7 +66,7 @@
 		  `math` VARCHAR( 20 ) NOT NULL ,
 		  `sum` INT NOT NULL ,
 		  PRIMARY KEY ( `math` )
-		  ) TYPE = MYISAM;";
+		  )";
 
 	$sql[4] = "INSERT INTO ".$db_prefix."captcha_math (
 			`math` ,
@@ -92,25 +93,25 @@
 		  `user_show_email` TINYINT( 1 ) NOT NULL ,
 		  `checked` TINYINT( 1 ) NOT NULL ,
 		  `isspam` TINYINT( 1 ) NOT NULL
-		  ) TYPE = MYISAM;";
+		  )";
 
 
 	$sql[6] = "CREATE TABLE ".$db_prefix."lastip (
 		  `lastIP` VARCHAR( 15 ) NOT NULL ,
 		  PRIMARY KEY ( `lastIP` )
-		  ) TYPE = MYISAM;";
+		  )";
 
 
 	$sql[7] = "CREATE TABLE ".$db_prefix."settings (
-		  `title` VARCHAR(255) NOT NULL DEFAULT 'MGB 0.6.x',
-		  `h_author` VARCHAR(255) NOT NULL, 
-		  `h_domain` VARCHAR(255) NOT NULL, 
-		  `gb_path` VARCHAR(255) NOT NULL, 
+		  `title` VARCHAR(255) NOT NULL DEFAULT 'MGB 0.6.x OpenSource Guestbook',
+		  `h_author` VARCHAR(255) NOT NULL DEFAULT '".$admin_name."', 
+		  `h_domain` VARCHAR(255) NOT NULL DEFAULT '".$server_name."', 
+		  `gb_path` VARCHAR(255) NOT NULL DEFAULT '".$gb_path."', 
 		  `h_keywords` VARCHAR(255) NOT NULL, 
 		  `h_description` VARCHAR(255) NOT NULL, 
-		  `admin_name` VARCHAR(255) NOT NULL, 
-		  `admin_email` VARCHAR(255) NOT NULL, 
-		  `admin_gbemail` VARCHAR(255) NOT NULL, 
+		  `admin_name` VARCHAR(255) NOT NULL DEFAULT '".$admin_name."', 
+		  `admin_email` VARCHAR(255) NOT NULL DEFAULT '".$admin_email."', 
+		  `admin_gbemail` VARCHAR(255) NOT NULL DEFAULT '".$admin_gbemail."', 
 		  `sendmail_admin` TINYINT(1) NOT NULL, 
 		  `sendmail_admin_text` MEDIUMTEXT NOT NULL, 
 		  `sendmail_user` TINYINT(1) NOT NULL, 
@@ -121,33 +122,54 @@
 		  `template_path` VARCHAR(255) NOT NULL DEFAULT 'mgbModern',
 		  `template_style_path` VARCHAR(255) NOT NULL DEFAULT 'blue',
 		  `iconset_path` VARCHAR(255) NOT NULL DEFAULT 'default', 
-		  `language_path` VARCHAR(255) NOT NULL DEFAULT 'lang_german_utf8', 
+		  `language_path` VARCHAR(255) NOT NULL DEFAULT 'lang_english_utf8', 
 		  `badwords` MEDIUMTEXT NOT NULL, 
 		  `bbcode` TINYINT(1) NOT NULL DEFAULT '1', 
+		  `allow_img_tag` TINYINT(1) NOT NULL DEFAULT '0', 
+		  `max_img_width` INT(4) NOT NULL DEFAULT '400', 
+		  `max_img_height` INT(4) NOT NULL DEFAULT '400', 
+		  `center_img` TINYINT(1) NOT NULL DEFAULT '1', 
+		  `allow_flash_tag` TINYINT(1) NOT NULL DEFAULT '0', 
+		  `max_flash_width` INT(4) NOT NULL DEFAULT '400', 
+		  `max_flash_height` INT(4) NOT NULL DEFAULT '400', 
+		  `center_flash` TINYINT(1) NOT NULL DEFAULT '1', 
 		  `smileys` TINYINT(1) NOT NULL DEFAULT '1', 
+		  `smileys_break` TINYINT(2) NOT NULL DEFAULT '11', 
+		  `smileys_order` VARCHAR(4) NOT NULL DEFAULT 'ASC', 
 		  `captcha` TINYINT(1) NOT NULL DEFAULT '1', 
-		  `captcha_method` TINYINT(1) NOT NULL DEFAULT '1', 
+		  `captcha_method` TINYINT(1) NOT NULL DEFAULT '0', 
+		  `captcha_coords_x` INT( 3 ) NOT NULL DEFAULT '20', 
+		  `captcha_coords_y` INT( 3 ) NOT NULL DEFAULT '25', 
+		  `captcha_color` VARCHAR( 6 ) NOT NULL DEFAULT '505050' ,
+		  `captcha_angle_1` INT( 4 ) NOT NULL DEFAULT '-10' ,
+		  `captcha_angle_2` INT( 4 ) NOT NULL DEFAULT '5' ,
 		  `akismet_plugin` TINYINT(1) NOT NULL DEFAULT '1', 
 		  `akismet_api` VARCHAR(50) NOT NULL, 
 		  `akismet_mark_as_spam` TINYINT(1) NOT NULL,
-		  `time_lock` TINYINT(1) NOT NULL,
+		  `time_lock` TINYINT(1) NOT NULL DEFAULT '1',
 		  `time_lock_value` INT(3) NOT NULL DEFAULT '30',
 		  `time_lock_maxtime` INT NOT NULL DEFAULT '180',
 		  `user_notification` TINYINT(1) NOT NULL DEFAULT '1', 
 		  `user_show_email` TINYINT(1) NOT NULL DEFAULT '1', 
-		  `session_timeout` INT(4) NOT NULL DEFAULT '1800', 
+		  `session_timeout` INT(4) NOT NULL DEFAULT '900', 
+		  `password_min_length` TINYINT(2) NOT NULL DEFAULT '8', 
 		  `moderated` TINYINT(1) NOT NULL DEFAULT '1', 
 		  `entries_per_page` TINYINT(2) NOT NULL DEFAULT '10',
-		  `entries_order` TINYINT(1) NOT NULL DEFAULT '0', 
+		  `entries_order` VARCHAR(11) NOT NULL DEFAULT 'ID', 
+		  `entries_order_asc_desc` VARCHAR(4) NOT NULL DEFAULT 'DESC', 
+		  `entries_numbering` TINYINT(1) NOT NULL DEFAULT '1', 
 		  `spam_protection` TINYINT(1) NOT NULL DEFAULT '1', 
 		  `ipblocker` TINYINT(1) NOT NULL DEFAULT '0', 
 		  `wordwrap` TINYINT(2) NOT NULL DEFAULT '60',
-		  `dateform` VARCHAR(5) NOT NULL DEFAULT 'd/m/Y', 
+		  `dateform` VARCHAR(5) NOT NULL DEFAULT 'd.m.Y', 
 		  `gravatar_show` TINYINT(1) NOT NULL DEFAULT '0',
 		  `gravatar_rating` TINYINT(1) NOT NULL DEFAULT '0', 
+		  `gravatar_type` TINYINT(1) NOT NULL DEFAULT '1', 
+		  `gravatar_size` INT(3) NOT NULL DEFAULT '50', 
+		  `gravatar_position` TINYINT(1) NOT NULL DEFAULT '1', 
 		  `version` VARCHAR(20) NOT NULL,
 		  PRIMARY KEY (`title`) 
-		 ) TYPE = MYISAM;";
+		 )";
 
 	$sql[8] = "INSERT INTO ".$db_prefix."settings (
 		  `title` ,
@@ -172,9 +194,24 @@
 		  `language_path` , 
 		  `badwords` , 
 		  `bbcode` , 
+		  `allow_img_tag` , 
+		  `max_img_width` , 
+		  `max_img_height` , 
+		  `center_img` , 
+		  `allow_flash_tag` , 
+		  `max_flash_width` , 
+		  `max_flash_height` , 
+		  `center_flash` , 
 		  `smileys` , 
+		  `smileys_break` , 
+		  `smileys_order` , 
 		  `captcha` , 
 		  `captcha_method` , 
+		  `captcha_coords_x` , 
+		  `captcha_coords_y` , 
+		  `captcha_color` , 
+		  `captcha_angle_1` , 
+		  `captcha_angle_2` , 
 		  `akismet_plugin` , 
 		  `akismet_api` , 
 		  `akismet_mark_as_spam` , 
@@ -184,19 +221,25 @@
 		  `user_notification` , 
 		  `user_show_email` , 
 		  `session_timeout` , 
+		  `password_min_length` , 
 		  `moderated` , 
 		  `entries_per_page` ,
 		  `entries_order` , 
+		  `entries_order_asc_desc` , 
+		  `entries_numbering` , 
 		  `spam_protection` , 
 		  `ipblocker` , 
 		  `wordwrap` ,
 		  `dateform` ,
 		  `gravatar_show` ,
 		  `gravatar_rating` , 
+		  `gravatar_type` ,
+		  `gravatar_size` , 
+		  `gravatar_position` , 
 		  `version`
 		  ) VALUES (
 		  'MGB ".MGB_VERSION."', 
-		  '', 
+		  '".$admin_name."', 
 		  '".$h_domain."', 
 		  '".$gb_path."', 
 		  '', 
@@ -217,27 +260,48 @@
 		  '".$_SESSION['install_language']."', 
 		  '', 
 		  '1', 
-		  '1', 
+		  '0', 
+		  '400', 
+		  '400', 
 		  '1', 
 		  '0', 
+		  '400', 
+		  '400', 
+		  '1', 
+		  '1', 
+		  '11', 
+		  'ASC', 
+		  '1', 
+		  '0', 
+		  '20', 
+		  '25', 
+		  '505050', 
+		  '-10', 
+		  '5', 
 		  '0', 
 		  '', 
 		  '1',
-		  '0',
+		  '1',
 		  '30',
 		  '180',
 		  '1',
 		  '1',
-		  '1800', 
+		  '900', 
+		  '8', 
 		  '1', 
 		  '10',
-		  '0',
+		  'ID',
+		  'DESC',
+		  '1',
 		  '1', 
 		  '0', 
 		  '60',
-		  'd/m/Y',
+		  'd.m.Y',
 		  '0',
 		  '0', 
+		  '1',
+		  '50', 
+		  '1', 
 		  '".MGB_VERSION."'
 		  );";
 
@@ -256,11 +320,12 @@
 		  `r_delete` TINYINT( 1 ) NOT NULL ,
 		  `r_edit` TINYINT( 1 ) NOT NULL ,
 		  `r_spam` TINYINT( 1 ) NOT NULL ,
+		  `r_edit_smilies` TINYINT( 1 ) NOT NULL ,
 		  `logged_in` INT( 255 ) NOT NULL ,
 		  `logged_out` TINYINT( 1 ) NOT NULL ,
 		  `np_key` VARCHAR( 16 ) NOT NULL ,
 		  `np_expiration` VARCHAR( 255 ) NOT NULL
-		  ) TYPE = MYISAM;";
+		  )";
 
 	$sql[10] = "INSERT INTO ".$db_prefix."user ( 
 		  `ID` ,
@@ -276,6 +341,7 @@
 		  `r_delete` ,
 		  `r_edit`,
 		  `r_spam`,
+		  `r_edit_smilies`,
 		  `logged_in` ,
 		  `logged_out`,
 		  `np_key` ,
@@ -294,15 +360,54 @@
 		  '1',
 		  '1',
 		  '1',
+		  '1',
 		  '".time()."',
 		  '1',
 		  '',
 		  ''
 		  );";
 
+	$sql[11] = "CREATE TABLE ".$db_prefix."smilies (
+		  `ID` INT NOT NULL AUTO_INCREMENT PRIMARY KEY ,
+		  `path` VARCHAR( 255 ) NOT NULL ,
+		  `replacement` VARCHAR( 255 ) NOT NULL ,
+		  `height` TINYINT( 4 ) NOT NULL ,
+		  `width` TINYINT( 4 ) NOT NULL
+		  )";
+
+	$sql[12] = "INSERT INTO ".$db_prefix."smilies ( 
+	  `ID` ,
+	  `path` ,
+	  `replacement` ,
+	  `height` ,
+	  `width`
+	  ) VALUES 	( NULL , 'smiley_smile.gif', ':smile:, :), :-)', '15', '15' ),
+				( NULL , 'smiley_wink.gif', ':wink:, ;), ;-)', '15', '15' ),
+				( NULL , 'smiley_lol.gif', ':lol:', '15', '15' ),
+				( NULL , 'smiley_biggrin.gif', ':biggrin:, :D, :-D', '15', '15' ),
+				( NULL , 'smiley_cool.gif', ':cool:, B), B-)', '15', '15' ),
+				( NULL , 'smiley_fun.gif', ':fun:, ^^', '15', '15' ),
+				( NULL , 'smiley_surprised.gif', ':surprised:, :O, :-O', '15', '15' ),
+				( NULL , 'smiley_tongue.gif', ':tongue:, :P, :-P', '15', '15' ),
+				( NULL , 'smiley_confused.gif', ':confused:, :-/', '15', '15' ),
+				( NULL , 'smiley_eek.gif', ':eek:, 8O, 8-O', '15', '15' ),
+				( NULL , 'smiley_doubt.gif', ':doubt:', '15', '15' ),
+				( NULL , 'smiley_neutral.gif', ':neutral:, :|, :-|', '15', '15' ),
+				( NULL , 'smiley_redface.gif', ':redface:', '15', '15' ),
+				( NULL , 'smiley_rolleyes.gif', ':rolleyes:', '15', '15' ),
+				( NULL , 'smiley_silenced.gif', ':silenced:', '15', '15' ),
+				( NULL , 'smiley_sad.gif', ':sad:, :(, :-(', '15', '15' ),
+				( NULL , 'smiley_cry.gif', ':cry:, :\'(, :\'-(', '15', '15' ),
+				( NULL , 'smiley_doh.gif', ':doh:', '15', '15' ),
+				( NULL , 'smiley_angry.gif', ':angry:', '15', '15' ),
+				( NULL , 'icon_arrow.gif', ':arrow:, ->', '15', '15' ),
+				( NULL , 'icon_exclaim.gif', ':exclaim:', '15', '15' ),
+				( NULL , 'icon_question.gif', ':question:', '15', '15' );";
+	$to = 12;
+
 	if(!isset($success)) { $success = 0; }
 	
-	for($i = 1; $i <= 10; $i++)
+	for($i = 1; $i <= $to; $i++)
 		{
 		$sqlcommand = $sql[$i];
 		$link = @mysql_connect($db_hostname, $db_username, $db_password) or die ("(mysql.php) Error: ".mysql_error());
@@ -314,6 +419,7 @@
 		else
 			{
 			echo mysql_error();
+			echo "<br><br>";
 			}
 		}
 ?>
